@@ -65,7 +65,7 @@ def get_next_todo_card():
     return my_cards[0]
 
 
-def get_current_working_ticket():
+def get_current_working_ticket(card_url):
     api = get_api()
 
     column = get_column(name=config['trello']['work_column_name'])
@@ -78,21 +78,29 @@ def get_current_working_ticket():
     work_card = None
 
     if len(my_cards) < 1:
-        raise ValueError("No working card; aborting.")
+        raise ValueError("No working card in your DOING list; aborting.")
 
-    if len(my_cards) == 1:
-        work_card = my_cards[0]
+    if not card_url:
+
+        if len(my_cards) == 1:
+            work_card = my_cards[0]
+
+        if len(my_cards) > 1:
+            for card in my_cards:
+                if len(card['idMembers']) == 1:
+                    if not work_card:
+                        work_card = card
+                    else:
+                        raise ValueError("Multiple available work cards; Try bb gh pr <card_url> ")
+    else:
+        url_cards = [card for card in my_cards if card['url'] == card_url]
+
+        if len(url_cards) > 0:
+            work_card = url_cards[0]
 
-    if len(my_cards) > 1:
-        for card in my_cards:
-            if len(card['idMembers']) == 1:
-                if not work_card:
-                    work_card = card
-                else:
-                    raise ValueError("Multiple work cards; cannot decide, aborting")
 
     if not work_card:
-        raise ValueError("No work card for me; aborting")
+        raise ValueError("The specified card_url is not in your DOING list")
 
     return work_card
 
